utils/logger library

Functions

logCreate(String path) → void
Logs that a file or directory was created at path.
logError(String message) → void
Prints an error message to stderr.
logInfo(String message) → void
Prints an informational message to stdout.
logSkip(String path) → void
Logs that a file at path was skipped because it already exists.
logSuccess(String message) → void
Prints a success message to stdout.
logWarning(String message) → void
Prints a warning message to stderr.
setLogColorsEnabled(bool enabled) → void
Enables or disables ANSI colors. Colors are auto-detected by default.