logSkip function
Logs that a file at path was skipped because it already exists.
Implementation
void logSkip(String path) =>
stdout.writeln(_paint(_grey, 'skipped $path (already exists)'));
Logs that a file at path was skipped because it already exists.
void logSkip(String path) =>
stdout.writeln(_paint(_grey, 'skipped $path (already exists)'));